aboutsummaryrefslogtreecommitdiff
path: root/base
diff options
context:
space:
mode:
authorMax Horn2003-11-29 12:10:23 +0000
committerMax Horn2003-11-29 12:10:23 +0000
commit493d64d91b9944cd91da6539cb41ee561ddafd92 (patch)
treed98f7c71d910672a12cadf47db98a375d0ee181d /base
parentd98479ee5dd0b70c88c37ea2c405694bf070ea88 (diff)
downloadscummvm-rg350-493d64d91b9944cd91da6539cb41ee561ddafd92.tar.gz
scummvm-rg350-493d64d91b9944cd91da6539cb41ee561ddafd92.tar.bz2
scummvm-rg350-493d64d91b9944cd91da6539cb41ee561ddafd92.zip
cleanup / added Engine::getGameDataPath()
svn-id: r11420
Diffstat (limited to 'base')
-rw-r--r--base/engine.cpp4
-rw-r--r--base/engine.h11
2 files changed, 11 insertions, 4 deletions
diff --git a/base/engine.cpp b/base/engine.cpp
index 4e8bb4a749..e86b9af4ef 100644
--- a/base/engine.cpp
+++ b/base/engine.cpp
@@ -74,6 +74,10 @@ const char *Engine::getSavePath() const {
#endif
}
+const char *Engine::getGameDataPath() const {
+ return _gameDataPath.c_str();
+}
+
void NORETURN CDECL error(const char *s, ...) {
#ifdef __PALM_OS__
char buf_input[256]; // 1024 is too big overflow the stack
diff --git a/base/engine.h b/base/engine.h
index a37cd08198..3d0f088dc3 100644
--- a/base/engine.h
+++ b/base/engine.h
@@ -45,13 +45,16 @@ public:
Engine(OSystem *syst);
virtual ~Engine();
- // Invoke the main engine loop using this method
+ /** Start the main engine loop. */
virtual void go() = 0;
- // Get the save game dir path
- const char *getSavePath() const;
+ /** Get the path to the save game directory. */
+ virtual const char *getSavePath() const;
- // Specific for each engine preparare of erroe string
+ /** Get the path to the game data directory. */
+ virtual const char *getGameDataPath() const;
+
+ /** Specific for each engine: prepare error string. */
virtual void errorString(const char *buf_input, char *buf_output) = 0;
};